# pylj

This is a simple python code to perform simple Lennard-Jonesium 2D simulation. 

The aim of this is to use in a computational/physical chemistry laboratory exersize. 

Install:

```
python setup.py build
python setup.py install 
```

Requires C++ complier.

### TODO

- General code cleanup
- API level documentation
- Unit testing
- Add example lessons
- Add Monte-Carlo

Contact:
arm61@bath.ac.uk
